translate.convert.prop2po.prop2po

Package translate :: Package convert :: Module prop2po :: Class prop2po |
[hide private]
[frames] | no frames]

# Class prop2po

source code

convert a .properties file to a .po file for handling the translation...

Instance Methods | [hide private]
convertstore(self, thepropfile, personality="java", duplicatestyle="msgctxt") converts a .properties file to a .po file... | source code
mergestore(self, origpropfile, translatedpropfile, personality="java", blankmsgstr=False, duplicatestyle="msgctxt") converts two .properties files to a .po file... | source code
convertunit(self, propunit, commenttype) Converts a .properties unit to a .po unit. | source code

Method Details | [hide private]

### convertunit(self, propunit, commenttype) | source code
Converts a .properties unit to a .po unit. Returns None if empty or not for translation.